//More information at: https://www.aeq-web.com

#include <ESP8266WiFi.h>

//---------------------BASIC SETTINGS ---------------------------
const char* ssid = "AEQ-NETWORK"; //WiFi Network Name
const char* password = "12345678"; //WiFi Password
int rl1_pin = 5; //Pin of relay 1 (D1 on NodeMCU)
int rl2_pin = 4; //Pin of relay 2 (D2 on NodeMCU)
//---------------------BASIC SETTINGS ---------------------------

int rl1_state = 0;
int rl2_state = 0;
String rl1_text = "OFF";
String rl2_text = "OFF";

WiFiServer server(80);

void setup() {
  Serial.begin(115200);
  delay(10);

  pinMode(rl1_pin, OUTPUT);
  pinMode(rl2_pin, OUTPUT);

  // Connect to WiFi network
  Serial.print("Try to connect to: ");
  Serial.println(ssid);
  WiFi.mode(WIFI_STA);
  WiFi.begin(ssid, password);
  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.print(".");
  }
  Serial.println("WiFi connected");
  server.begin();
  Serial.println("Local IP: ");
  Serial.println(WiFi.localIP());
}

void loop() {
  WiFiClient client = server.available();
  if (!client) {
    return;
  }
  while (!client.available()) {
    delay(1);
  }

  String req = client.readStringUntil('\r');
  client.flush();
  if (req.indexOf("?RL1ON") != -1) {
    rl1_state = 1;
    rl1_text = "ON";
    digitalWrite(rl1_pin, HIGH);
  } else if (req.indexOf("?RL1OFF") != -1) {
    rl1_state = 0;
    rl1_text = "OFF";
    digitalWrite(rl1_pin, LOW);
  }
  if (req.indexOf("?RL2ON") != -1) {
    rl2_state = 1;
    rl2_text = "ON";
    digitalWrite(rl2_pin, HIGH);
  } else if (req.indexOf("?RL2OFF") != -1) {
    rl2_state = 0;
    rl2_text = "OFF";
    digitalWrite(rl2_pin, LOW);
  }

  client.flush();
  client.println("HTTP/1.1 200 OK");
  client.println("Content-Type: text/html");
  client.println();
  client.println("<html>");
  client.println("<head>");
  client.println("<TITLE>SmartSwitch Control</TITLE>");
  client.println("</head>");
  client.println("<body>");
  client.println("<h1>SmartSwitch Control Center</h1>");
  client.println("<hr>");
  client.println("<br>");
  client.println("<table border='1'>");
  client.println("<tr>");
  client.println("<th>Output 1</th>");
  client.println("<th>");
  client.println(rl1_text);
  client.println("</th>");
  client.println("<tr>");
  client.println("<tr>");
  client.println("<th>Output 2</th>");
  client.println("<th>");
  client.println(rl2_text);
  client.println("</th>");
  client.println("<tr>");
  client.println("<tr>");
  client.println("<th>");
  if (rl1_state == 1) {
    client.println("<a href=\"/?RL1OFF\"\">TURN RLY1 OFF</a>");
  } else {
    client.println("<a href=\"/?RL1ON\"\">TURN RLY1 ON</a>");
  }
  client.println("</th>");
  client.println("<th>");
  if (rl2_state == 1) {
    client.println("<a href=\"/?RL2OFF\"\">TURN RLY2 OFF</a>");
  } else {
    client.println("<a href=\"/?RL2ON\"\">TURN RLY2 ON</a>");
  }
  client.println("</th>");
  client.println("<tr>");
  client.println("</table>");
  client.println("</body>");
  client.println("</html>");
  delay(10);
  Serial.println("Client disonnected");
}
